"""This is a standard way to include a multiple-line comment in your code."""
def print_lol(the_list,level):
    """这个函数有一个位置参数，名为“the_list”，
这可以是任何Python列表（包含或不包含嵌套列表），
所提供列表中的各个数据项会（递归地）打印到屏幕上，而且各占一行"""
    for each_item in the_list:
        if isinstance(each_item,list):
            print_lol(each_item,level+1)
        else:
            for tab_stop in range(level):
                print("\t",end='')
            print(each_item)
