from distutils.core import setup

setup(
    name = 'jswanquan',
    version = '1.1.0',
    py_modules = ['jswanquan'],
    author = 'momopiao',
    author_email = 'ximu15270487613@163.com',
    url = 'http://www/headfirstlabs.com',
    description = 'A simple printer of nested lists',
    )
